@@ -6,8 +6,10 @@ It contains:
     - FlipConv2d (Special Conv2d layer that's almost invariant to image flipping) for Convnets,
     - MultiHeadAttention implemented in the transformers paper (Attention is all you need).
     - MultiHeadAttentionV2 is a modified version.
+    - ConvMixerLayer (implemented in ConvMixer) for Convnets
 """
 from .FlipConv2d import FlipConv2d
 from .SE import SE
 from .MultiHeadAttention import MultiHeadAttention, MultiHeadAttentionV2
-from .DenseBlock import DenseBlock
\ No newline at end of file
+from .DenseBlock import DenseBlock
+from .ConvMixerLayer import ConvMixerLayer
\ No newline at end of file
